@@ -5,7 +5,8 @@ from urllib.request import urlopen
 from shutil import copyfileobj
 
 # External
-import pickle5 as pickle
+from pandas import read_csv
+#import pickle5 as pickle
 from sklearn.preprocessing import MinMaxScaler
 
 # Locals
@@ -16,18 +17,22 @@ def get_data(n_out, n_timestamp, data_path='./', verbose=False, **kwargs):
     logging.info('='*40)
     logging.info('DATASET:')
     logging.info('-'*40)
-    if data_path=='temperature': 
-        data_path = 'daily-min-temperatures.pickle' 
-        # data_path = 'daily-min-temperatures.csv' 
+    if data_path=='temperature':
+        # data_path = 'daily-min-temperatures.pickle' 
+        data_path = 'daily-min-temperatures.csv'
         if os.path.exists(data_path)==False:
             logging.info('\tDownloading dataset...')
             url_path = 'https://gitlab.com/hpo-uq/hyppo/-/raw/master/data/temperature/'+data_path
             with urlopen(url_path) as in_stream, open(data_path, 'wb') as out_file:
                 copyfileobj(in_stream, out_file)
+    assert os.path.exists(os.path.expandvars(data_path)), 'Dataset at %s does not exist. Abort.' % data_path
     logging.info('\tLoading dataset...')
-    with open(os.path.expandvars(data_path), "rb") as fh:
-        dataset = pickle.load(fh)
-    # dataset = read_csv(os.path.expandvars(data_path), header=0, index_col=0, engine='python')
+    while True:
+        try:
+            dataset = read_csv(os.path.expandvars(data_path), header=0, index_col=0, engine='python')
+            break
+        except:
+            pass
     logging.info('\tSize of dataset: %i' % len(dataset))
     if verbose:
         show_acf(dataset)
