@@ -1,12 +1,14 @@
 # System
 import os
-import pickle
 import logging
 
+# External
+import pickle5 as pickle
+
 # Local
 from .dnnmodels import get_fct
 
-def get_hyperprms(x_sc=None,record=None,library=None,**kwargs):
+def get_hyperprms(trainer, x_sc=None,record=None,library=None,**kwargs):
     """
     This function handles the recording and/or loading of the
     compelte hyperparameter set ready-to-use for training.
@@ -31,7 +33,10 @@ def get_hyperprms(x_sc=None,record=None,library=None,**kwargs):
         hyperprms = pickle.load(filehandler)
     else:
         # Dictionary with hyperparameter values
-        hyperprms = set_hyperparams(x_sc, library, **kwargs)
+        if trainer=='internal':
+            hyperprms = set_hyperparams(x_sc, library, **kwargs)
+        else:
+            hyperprms = x_sc
         if record!=None:
             filehandler = open(os.path.expandvars(record), 'wb')
             pickle.dump(hyperprms, filehandler)
@@ -98,13 +103,13 @@ def set_hyperparams(random_set, library, **kwargs):
         'kernel':3,
         'lag':0,
         'layers':1,
-        'opt_args':{},
+        'lr':0.001,
         'loss':'mean_squared_error',
         'loss_args': {},
         'maxpool':2,
         'nodes':10,
-        'opt_args':{},
         'optimizer':'Adam',
+        'opt_args':{},
         'padding':'same',
         'recurrent_activation':'relu',
         'recurrent_dropout':0,
@@ -112,6 +117,9 @@ def set_hyperparams(random_set, library, **kwargs):
     }
     # Merge default and input values
     hpo_set = {**params, **random_set}
+    # If existing, move random learning rate to relevant sub-dictionary
+    hpo_set['opt_args']['lr'] = hpo_set['lr']
+    del(hpo_set['lr'])
     # Available loss[0~13], optimizers[0~6] and activation[0~10] function in Keras
     activations = [
         'elu',
